plone.app.event.dx.behaviors — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.dx.behaviors

Behaviors to enable calendarish event extension to dexterity content types.

class `plone.app.event.dx.behaviors.` `EventAccessor`(context)

  Generic event accessor adapter implementation for Dexterity content objects.

class `plone.app.event.dx.behaviors.` `FakeZone`

  Fake timezone to be applied to EventBasic start and end dates before data_postprocessing event handler sets the correct one.

exception `plone.app.event.dx.behaviors.` `StartBeforeEnd`

  error_invalid_date

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »